offset property

SliverOffset get offset

The offset to this child relative to the parent, can be set during layout or paint with position.

This getter may return erroneous values if a transform is applied to the child since the coordinate space would be skewed.

If the parent is not a sliver, the axis direction of the offset is assumed to be down, such that dx is the cross axis and dy is the main axis.

Implementation

SliverOffset get offset {
  return _parent.wrapOffset(Offset(transform[12], transform[13]), size);
}
set offset (Offset newOffset)

Implementation

set offset(Offset newOffset) => position(newOffset);