LayerKey<T extends Layer> class

Cache for Layer objects, used by BoxyLayerContext methods.

Preserving Layers between paints can significantly improve performance in some cases, this class provides a convenient way of identifying them.

See also:

Constructors

LayerKey()

Properties

handle LayerHandle<T>
The underlying handle that prevents the layer from being disposed prematurely.
final
hashCode int
The hash code for this object.
no setterinherited
layer ↔ T?
The current cached layer.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited