handle property
The underlying handle that prevents the layer from being disposed prematurely.
Implementation
final handle = LayerHandle<T>();
The underlying handle that prevents the layer from being disposed prematurely.
final handle = LayerHandle<T>();