activeAnimations property

Map<UniqueKey, TreeViewNodesAnimation> get activeAnimations

The currently active TreeViewNode animations.

Since the index of animating nodes can change at any time, the unique key is used to track an animation of nodes across frames.

Implementation

Map<UniqueKey, TreeViewNodesAnimation> get activeAnimations {
  return _activeAnimations;
}
set activeAnimations (Map<UniqueKey, TreeViewNodesAnimation> value)

Implementation

set activeAnimations(Map<UniqueKey, TreeViewNodesAnimation> value) {
  if (_activeAnimations == value) {
    return;
  }
  _activeAnimations = value;
  markNeedsLayout(withDelegateRebuild: true);
}