RestorableShadTabsController<T> class
A restorable version of ShadTabsController for state persistence.
Useful for maintaining tab selection across widget rebuilds and state restoration.
- Inheritance
-
- Object
- ChangeNotifier
- RestorableProperty<
ShadTabsController< T> > - RestorableListenable<
ShadTabsController< T> > - RestorableChangeNotifier<
ShadTabsController< T> > - RestorableShadTabsController
Constructors
- RestorableShadTabsController({required T value})
-
Creates a RestorableShadTabsController.
factory
- RestorableShadTabsController.fromValue(T value)
- Creates a RestorableShadTabsController from a given value.
Properties
- enabled → bool
-
Whether the object currently returned by toPrimitives should be included
in the restoration state.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isRegistered → bool
-
Whether this property is currently registered with a RestorationMixin.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected ↔ T
-
getter/setter pair
-
state
→ State<
StatefulWidget> -
The State object that this property is registered with.
no setterinherited
-
value
→ ShadTabsController<
T> -
The Listenable stored in this property.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
createDefaultValue(
) → ShadTabsController< T> -
Called by the RestorationMixin if no restoration data is available to
restore the value of the property from to obtain the default value for the
property.
override
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
fromPrimitives(
Object? data) → ShadTabsController< T> -
Called by the RestorationMixin to convert the
datapreviously retrieved from toPrimitives back into an object of typeTthat this property should wrap.override -
initWithValue(
ShadTabsController< T> value) → void -
Called by the RestorationMixin with the
valuereturned by either createDefaultValue or fromPrimitives to set the value that this property currently wraps.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toPrimitives(
) → Object? -
Called by the RestorationMixin to retrieve the information that this
property wants to store in the restoration data.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited