bottom property

Widget? bottom
final

An optional widget to display at the bottom of the alert, below the main content. This can be used to add additional information or controls.

Implementation

final Widget? bottom;