trailing property
An optional widget to display at the trailing edge of the alert, after the main content. This can be used to add additional information or controls.
Implementation
final Widget? trailing;
An optional widget to display at the trailing edge of the alert, after the main content. This can be used to add additional information or controls.
final Widget? trailing;