descriptionStyle property
Style for the description text, overrides theme default if provided.
Controls font size, weight, color, and other text properties of the
description.
Implementation
final TextStyle? descriptionStyle;
Style for the description text, overrides theme default if provided.
Controls font size, weight, color, and other text properties of the
description.
final TextStyle? descriptionStyle;