backgroundColor property
The background color of the page, defaults to ShadTheme.of(context).colorScheme.background.
Implementation
final Color? backgroundColor;
The background color of the page, defaults to ShadTheme.of(context).colorScheme.background.
final Color? backgroundColor;