offset property
The offset between the border and the widget.
NOTE: This is supported only by the secondaryBorder, because the border is drawn outward of the widget.
Implementation
final double? offset;
The offset between the border and the widget.
NOTE: This is supported only by the secondaryBorder, because the border is drawn outward of the widget.
final double? offset;