ShadBreakpoint class sealed

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator <(ShadBreakpoint other) bool
operator <=(ShadBreakpoint other) bool
operator ==(Object other) bool
The equality operator.
inherited
operator >(ShadBreakpoint other) bool
operator >=(ShadBreakpoint other) bool

Static Methods

lerp(ShadBreakpoint a, ShadBreakpoint b, double t) double