ShadBreakpointLG class

Inheritance

Constructors

ShadBreakpointLG(double value)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator <(ShadBreakpoint other) bool
inherited
operator <=(ShadBreakpoint other) bool
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator >(ShadBreakpoint other) bool
inherited
operator >=(ShadBreakpoint other) bool
inherited