ShadBreakpoints class

Constructors

ShadBreakpoints({double tn = 0, double sm = 640, double md = 768, double lg = 1024, double xl = 1280, double xxl = 1536})

Properties

hashCode int
The hash code for this object.
no setterinherited
lg ShadBreakpoint
final
md ShadBreakpoint
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm ShadBreakpoint
final
tn ShadBreakpoint
final
xl ShadBreakpoint
final
xxl ShadBreakpoint
final

Methods

fromWidth(double width) ShadBreakpoint
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lerp(ShadBreakpoints? a, ShadBreakpoints? b, double t) ShadBreakpoints?