enabled property
Whether the button is interactive, defaults to true. If false, the button is disabled, visually dimmed, and non-responsive.
Implementation
final bool enabled;
Whether the button is interactive, defaults to true. If false, the button is disabled, visually dimmed, and non-responsive.
final bool enabled;