focusNode property
The focus node for keyboard navigation, created internally if not provided. Enables focus handling and shortcuts like Enter key activation.
Implementation
final FocusNode? focusNode;
The focus node for keyboard navigation, created internally if not provided. Enables focus handling and shortcuts like Enter key activation.
final FocusNode? focusNode;