pressedBackgroundColor property
The background color of the button when pressed, overriding the theme default if provided. Applied during tap or long-press interactions.
Implementation
final Color? pressedBackgroundColor;
The background color of the button when pressed, overriding the theme default if provided. Applied during tap or long-press interactions.
final Color? pressedBackgroundColor;