ShadButtonSizeTheme class

Annotations

Constructors

ShadButtonSizeTheme({bool canMerge = true, required double height, required EdgeInsetsGeometry padding, double? width})
const

Properties

canMerge bool
no setter
hashCode int
The hash code for this object.
no setterinherited
height double
final
padding EdgeInsetsGeometry
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
final

Methods

copyWith({double? height, EdgeInsetsGeometry? padding, double? width}) ShadButtonSizeTheme
inherited
merge(ShadButtonSizeTheme? other) ShadButtonSizeTheme
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited