ShadButtonSizesTheme class

The theme for the predefined sizes of ShadButton.

Annotations

Constructors

ShadButtonSizesTheme({bool canMerge = true, ShadButtonSizeTheme? regular, ShadButtonSizeTheme? sm, ShadButtonSizeTheme? lg, ShadButtonSizeTheme? icon})
const

Properties

canMerge bool
no setter
hashCode int
The hash code for this object.
no setterinherited
icon ShadButtonSizeTheme?
final
lg ShadButtonSizeTheme?
final
regular ShadButtonSizeTheme?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm ShadButtonSizeTheme?
final

Methods

copyWith({ShadButtonSizeTheme? regular, ShadButtonSizeTheme? sm, ShadButtonSizeTheme? lg, ShadButtonSizeTheme? icon}) ShadButtonSizesTheme
inherited
merge(ShadButtonSizesTheme? other) ShadButtonSizesTheme
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited