backgroundColor property
The background color of the button when not hovered or pressed, overriding
the theme default if provided. Changes based on variant if not
explicitly set.
Implementation
final Color? backgroundColor;
The background color of the button when not hovered or pressed, overriding
the theme default if provided. Changes based on variant if not
explicitly set.
final Color? backgroundColor;