pressedForegroundColor property
The foreground color of the button when pressed, overriding the theme default if provided. Applied to content during tap or long-press interactions.
Implementation
final Color? pressedForegroundColor;
The foreground color of the button when pressed, overriding the theme default if provided. Applied to content during tap or long-press interactions.
final Color? pressedForegroundColor;