weekNumbersTextStyle property
The text style of the week numbers, defaults to
textTheme.muted.copyWith(fontSize: 12.8)
Implementation
final TextStyle? weekNumbersTextStyle;
The text style of the week numbers, defaults to
textTheme.muted.copyWith(fontSize: 12.8)
final TextStyle? weekNumbersTextStyle;