direction property
The text direction for arranging the checkbox and label/sublabel. Defaults to null (inherits from context) if not specified.
Implementation
final TextDirection? direction;
The text direction for arranging the checkbox and label/sublabel. Defaults to null (inherits from context) if not specified.
final TextDirection? direction;