enabled property
Whether the checkbox is interactive. Defaults to true; if false, the checkbox is disabled and visually dimmed.
Implementation
final bool enabled;
Whether the checkbox is interactive. Defaults to true; if false, the checkbox is disabled and visually dimmed.
final bool enabled;