focusNode property
The focus node for keyboard navigation and focus handling. If null, an internal focus node is created.
Implementation
final FocusNode? focusNode;
The focus node for keyboard navigation and focus handling. If null, an internal focus node is created.
final FocusNode? focusNode;