value property
Whether the checkbox is checked (true) or unchecked (false). Required to set the initial state of the checkbox.
Implementation
final bool value;
Whether the checkbox is checked (true) or unchecked (false). Required to set the initial state of the checkbox.
final bool value;