ShadColorScheme class

Implementers
Annotations

Constructors

ShadColorScheme({bool canMerge = true, required Color background, required Color foreground, required Color card, required Color cardForeground, required Color popover, required Color popoverForeground, required Color primary, required Color primaryForeground, required Color secondary, required Color secondaryForeground, required Color muted, required Color mutedForeground, required Color accent, required Color accentForeground, required Color destructive, required Color destructiveForeground, required Color border, required Color input, required Color ring, required Color selection, Map<String, Color> custom = const {}})
const
ShadColorScheme.fromName(String name, {Brightness brightness = Brightness.light})
factory

Properties

accent Color
final
accentForeground Color
final
background Color
final
border Color
final
canMerge bool
no setter
card Color
final
cardForeground Color
final
custom Map<String, Color>
final
destructive Color
final
destructiveForeground Color
final
foreground Color
final
hashCode int
The hash code for this object.
no setteroverride
input Color
final
muted Color
final
mutedForeground Color
final
popover Color
final
popoverForeground Color
final
primary Color
final
primaryForeground Color
final
ring Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Color
final
secondaryForeground Color
final
selection Color
final

Methods

copyWith({Color? background, Color? foreground, Color? card, Color? cardForeground, Color? popover, Color? popoverForeground, Color? primary, Color? primaryForeground, Color? secondary, Color? secondaryForeground, Color? muted, Color? mutedForeground, Color? accent, Color? accentForeground, Color? destructive, Color? destructiveForeground, Color? border, Color? input, Color? ring, Color? selection, Map<String, Color>? custom}) ShadColorScheme
Creates a copy of this ShadColorScheme but with the given fields replaced with the new values.
merge(ShadColorScheme? other) ShadColorScheme
Merges this ShadColorScheme with other.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override