itemPadding property
The padding of the context menu item, defaults to
EdgeInsets.symmetric(horizontal: 4).
Implementation
final EdgeInsetsGeometry? itemPadding;
The padding of the context menu item, defaults to
EdgeInsets.symmetric(horizontal: 4).
final EdgeInsetsGeometry? itemPadding;