selectedBackgroundColor property
The background color of the context menu item when it is selected,
defaults to theme.colorScheme.accent.
Implementation
final Color? selectedBackgroundColor;
The background color of the context menu item when it is selected,
defaults to theme.colorScheme.accent.
final Color? selectedBackgroundColor;