textStyle property
The text style of the context menu item, defaults to
small.copyWith(fontWeight: FontWeight.normal).
Implementation
final TextStyle? textStyle;
The text style of the context menu item, defaults to
small.copyWith(fontWeight: FontWeight.normal).
final TextStyle? textStyle;