trailingTextStyle property
The text style of the trailing widget, defaults to
muted.copyWith(fontSize: 12, height: 1).
Implementation
final TextStyle? trailingTextStyle;
The text style of the trailing widget, defaults to
muted.copyWith(fontSize: 12, height: 1).
final TextStyle? trailingTextStyle;