calendarHeaderTextStyle property
The text style of the header, defaults to effectiveTextTheme.small
Implementation
final TextStyle? calendarHeaderTextStyle;
The text style of the header, defaults to effectiveTextTheme.small
final TextStyle? calendarHeaderTextStyle;