dayButtonOutsideMonthTextStyle property
The text style of the day buttons outside the month, defaults to
textTheme.muted
Implementation
final TextStyle? dayButtonOutsideMonthTextStyle;
The text style of the day buttons outside the month, defaults to
textTheme.muted
final TextStyle? dayButtonOutsideMonthTextStyle;