dayButtonTextStyle property
The text style of the day button, defaults to
textTheme.small.copyWith(
fontWeight: FontWeight.normal,
color: colorScheme.foreground,
)
Implementation
final TextStyle? dayButtonTextStyle;
The text style of the day button, defaults to
textTheme.small.copyWith(
fontWeight: FontWeight.normal,
color: colorScheme.foreground,
)
final TextStyle? dayButtonTextStyle;