insideRangeDayButtonTextStyle property
The text style of the inside range day button, defaults to
textTheme.small.copyWith(
color: colorScheme.foreground,
)
Implementation
final TextStyle? insideRangeDayButtonTextStyle;
The text style of the inside range day button, defaults to
textTheme.small.copyWith(
color: colorScheme.foreground,
)
final TextStyle? insideRangeDayButtonTextStyle;