weekNumbersHeaderTextStyle property
The header text style of the week numbers, defaults to
textTheme.muted.copyWith(fontSize: 12.8)
Implementation
final TextStyle? weekNumbersHeaderTextStyle;
The header text style of the week numbers, defaults to
textTheme.muted.copyWith(fontSize: 12.8)
final TextStyle? weekNumbersHeaderTextStyle;