weekNumbersTextAlign property
The text align of the week numbers, defaults to TextAlign.center
Implementation
final TextAlign? weekNumbersTextAlign;
The text align of the week numbers, defaults to TextAlign.center
final TextAlign? weekNumbersTextAlign;