ShadDateTime extension
- on
Properties
- daysInMonth → int
-
Available on DateTime, provided by the ShadDateTime extension
no setter - endOfDay → DateTime
-
Available on DateTime, provided by the ShadDateTime extension
no setter - endOfMonth → DateTime
-
Available on DateTime, provided by the ShadDateTime extension
no setter - endOfWeek → DateTime
-
Available on DateTime, provided by the ShadDateTime extension
no setter - nextDay → DateTime
-
Available on DateTime, provided by the ShadDateTime extension
no setter - nextMonth → DateTime
-
Available on DateTime, provided by the ShadDateTime extension
no setter - ordinalDate → int
-
Available on DateTime, provided by the ShadDateTime extension
The ordinal date, the number of days since December 31st the previous year.no setter - previousDay → DateTime
-
Available on DateTime, provided by the ShadDateTime extension
no setter - previousMonth → DateTime
-
Available on DateTime, provided by the ShadDateTime extension
no setter - startOfDay → DateTime
-
Available on DateTime, provided by the ShadDateTime extension
no setter - startOfMonth → DateTime
-
Available on DateTime, provided by the ShadDateTime extension
no setter - startOfWeek → DateTime
-
Available on DateTime, provided by the ShadDateTime extension
no setter - weekNumber → int
-
Available on DateTime, provided by the ShadDateTime extension
The ISO 8601 week number1..53.no setter
Methods
-
addDays(
int days) → DateTime -
Available on DateTime, provided by the ShadDateTime extension
Add days to the current date without taking into account the different daylight -
getOrdinalDay(
) → String -
Available on DateTime, provided by the ShadDateTime extension
-
isLeapYear(
int value) → bool -
Available on DateTime, provided by the ShadDateTime extension
-
isSameDay(
DateTime other) → bool -
Available on DateTime, provided by the ShadDateTime extension
-
isSameDayOrGreatier(
DateTime other) → bool -
Available on DateTime, provided by the ShadDateTime extension
-
isSameDayOrLower(
DateTime other) → bool -
Available on DateTime, provided by the ShadDateTime extension
-
removeDays(
int days) → DateTime -
Available on DateTime, provided by the ShadDateTime extension
Remove days from the current date without taking into account the different daylight