descriptionPinned property
Whether the description is pinned when scrolling and scrollable is true.
Defaults to false if not specified.
Implementation
final bool? descriptionPinned;
Whether the description is pinned when scrolling and scrollable is true.
Defaults to false if not specified.
final bool? descriptionPinned;