scrollPadding property
The padding applied when the dialog content is scrollable.
If not specified, no additional padding is applied to the scrollable content.
Implementation
final EdgeInsetsGeometry? scrollPadding;
The padding applied when the dialog content is scrollable.
If not specified, no additional padding is applied to the scrollable content.
final EdgeInsetsGeometry? scrollPadding;