actionsPinned property
Whether the actions are pinned when scrolling and scrollable is true.
Defaults to true if not specified.
Implementation
final bool? actionsPinned;
Whether the actions are pinned when scrolling and scrollable is true.
Defaults to true if not specified.
final bool? actionsPinned;