removeBorderRadiusWhenTiny property
Whether to remove the border radius on small screens. Defaults to true if not specified.
Implementation
final bool? removeBorderRadiusWhenTiny;
Whether to remove the border radius on small screens. Defaults to true if not specified.
final bool? removeBorderRadiusWhenTiny;