titlePinned property
Whether the title is pinned when scrolling and scrollable is true.
Defaults to false if not specified.
Implementation
final bool? titlePinned;
Whether the title is pinned when scrolling and scrollable is true.
Defaults to false if not specified.
final bool? titlePinned;