effectiveId property
String
get
effectiveId
The effective identifier for the field, using the provided ID or an auto-generated one.
Implementation
String get effectiveId => widget.id ?? _internalId;
The effective identifier for the field, using the provided ID or an auto-generated one.
String get effectiveId => widget.id ?? _internalId;