ShadFormState class
The state class for ShadForm managing form fields and validation
Constructors
Properties
-
autovalidateMode
↔ ValueNotifier<
AutovalidateMode> -
latefinal
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- enabled → bool
-
Whether the form is enabled
no setter
- fields → ShadFormFields
-
Returns the registered form fields
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
initialValue
→ Map<
String, dynamic> -
Returns the initial form values
no setter
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
-
rawValue
→ Map<
String, dynamic> -
Returns an unmodifiable view of the current form values without
transformations applied
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ Map<
String, dynamic> -
Returns an unmodifiable view of the current form values with
transformations applied
no setter
- widget → ShadForm
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant ShadForm oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
getFieldValue(
String id) → dynamic -
Gets a value from the nested map value map using
fieldIdSeparator. -
initState(
) → void -
Called when this object is inserted into the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
registerField(
String id, ShadFormBuilderFieldState< ShadFormBuilderField, dynamic> field) → void - Registers a form field with the specified id
-
removeFieldValue(
String id, {bool notifyField = false}) → void - Removes internal field value
-
reset(
) → void - Resets the form to its initial state
-
save(
) → void - Saves the current form state
-
saveAndValidate(
{bool focusOnInvalid = true, bool autoScrollWhenFocusOnInvalid = false}) → bool - Saves and validates the form with optional focus and scroll behavior
-
setFieldError(
String id, String? error) → void -
Sets forced internal error for a form field
Throws if the field with
idis not registered with the form. -
setFieldValue<
T> (String id, T? value, {bool notifyField = true}) → void - Sets the value for a form field with the specified id
-
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
setValue(
Map< String, dynamic> value, {bool notifyFields = true, bool removeMissing = false, bool notifyRemovedFields = false}) → void - Merges the provided entries into the form value; optionally removes keys missing from the provided map.
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
unregisterField(
String id, ShadFormBuilderFieldState< ShadFormBuilderField, dynamic> field) → void - Unregisters a form field
-
validate(
{bool focusOnInvalid = true, bool autoScrollWhenFocusOnInvalid = false}) → bool - Validates the form with optional focus and scroll behavior
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited