ShadHoverStrategy enum

Inheritance
Available extensions

Values

onTapDown → const ShadHoverStrategy
onTapUp → const ShadHoverStrategy
onTapCancel → const ShadHoverStrategy
onLongPressStart → const ShadHoverStrategy
onLongPressCancel → const ShadHoverStrategy
onLongPressUp → const ShadHoverStrategy
onLongPressDown → const ShadHoverStrategy
onLongPressEnd → const ShadHoverStrategy
onDoubleTapDown → const ShadHoverStrategy
onDoubleTapCancel → const ShadHoverStrategy
onForcePressStart → const ShadHoverStrategy
onForcePressEnd → const ShadHoverStrategy
onTap → const ShadHoverStrategy
onTapOutside → const ShadHoverStrategy

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ShadHoverStrategy>
A constant List of the values in this enum, in order of their declaration.