onFocusChange property
Callback invoked when the focus state changes, providing the new focus value. Complements internal focus state management.
Implementation
final ValueChanged<bool>? onFocusChange;
Callback invoked when the focus state changes, providing the new focus value. Complements internal focus state management.
final ValueChanged<bool>? onFocusChange;