enabled property
Whether the input is interactive. Defaults to true; if false, the input is disabled and visually dimmed.
Implementation
final bool enabled;
Whether the input is interactive. Defaults to true; if false, the input is disabled and visually dimmed.
final bool enabled;