gap property
The gap between the input field and its leading/trailing widgets. Defaults to 8 if not specified.
Implementation
final double? gap;
The gap between the input field and its leading/trailing widgets. Defaults to 8 if not specified.
final double? gap;