inputFormatters property
The list of formatters to apply to the input text. Controls text transformation (e.g., masking, filtering).
Implementation
final List<TextInputFormatter>? inputFormatters;
The list of formatters to apply to the input text. Controls text transformation (e.g., masking, filtering).
final List<TextInputFormatter>? inputFormatters;