inputPadding property
The padding around the editable text within the input field. Defaults to EdgeInsets.zero if not specified.
Implementation
final EdgeInsetsGeometry? inputPadding;
The padding around the editable text within the input field. Defaults to EdgeInsets.zero if not specified.
final EdgeInsetsGeometry? inputPadding;