onPasteFilesError property
Called when an error occurs while extracting files from the clipboard.
Only works on web. On other platforms, this callback is never invoked.
Implementation
final ValueChanged<Object>? onPasteFilesError;
Called when an error occurs while extracting files from the clipboard.
Only works on web. On other platforms, this callback is never invoked.
final ValueChanged<Object>? onPasteFilesError;