readOnly property
Whether the input is read-only. Defaults to false; if true, editing is disabled but selection may still be enabled.
Implementation
final bool readOnly;
Whether the input is read-only. Defaults to false; if true, editing is disabled but selection may still be enabled.
final bool readOnly;