scrollPadding property
The padding applied around the input when scrolling to keep it visible. Defaults to EdgeInsets.all(20).
Implementation
final EdgeInsets scrollPadding;
The padding applied around the input when scrolling to keep it visible. Defaults to EdgeInsets.all(20).
final EdgeInsets scrollPadding;