smartDashesType property
The smart dashes behavior for the input. Defaults to enabled if not obscured, disabled if obscured.
Implementation
final SmartDashesType smartDashesType;
The smart dashes behavior for the input. Defaults to enabled if not obscured, disabled if obscured.
final SmartDashesType smartDashesType;