smartQuotesType property
The smart quotes behavior for the input. Defaults to enabled if not obscured, disabled if obscured.
Implementation
final SmartQuotesType smartQuotesType;
The smart quotes behavior for the input. Defaults to enabled if not obscured, disabled if obscured.
final SmartQuotesType smartQuotesType;