style property
The text style for the input content. Defaults to the theme’s muted style with foreground color if not specified.
Implementation
final TextStyle? style;
The text style for the input content. Defaults to the theme’s muted style with foreground color if not specified.
final TextStyle? style;