textAlign property
The horizontal alignment of the text within the input. Defaults to TextAlign.start.
Implementation
final TextAlign textAlign;
The horizontal alignment of the text within the input. Defaults to TextAlign.start.
final TextAlign textAlign;