textInputAction property
The action to perform when the user submits the input. Defaults to null, relying on platform behavior.
Implementation
final TextInputAction? textInputAction;
The action to perform when the user submits the input. Defaults to null, relying on platform behavior.
final TextInputAction? textInputAction;