inputFormatters property
The input formatters for the input of each slot, unless overridden in the slot
Implementation
final List<TextInputFormatter>? inputFormatters;
The input formatters for the input of each slot, unless overridden in the slot
final List<TextInputFormatter>? inputFormatters;