ShadInputOTPState class

Inheritance

Constructors

ShadInputOTPState()

Properties

context BuildContext
The location in the tree where this widget builds.
no setterinherited
groups int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
listenable Listenable
getter/setter pair
mounted bool
Whether this State object is currently in a tree.
no setterinherited
registeredOTPs List<({TextEditingController controller, FocusNode focusNode})>
final
result ValueNotifier<String>
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>
latefinal
widget ShadInputOTP
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant ShadInputOTP oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
initState() → void
Called when this object is inserted into the tree.
override
jumpToNextSlot() → void
jumpToPreviousSlot({bool clear = false}) → void
jumpToSlot(int index, {bool clear = false}) → void
listenToSlot(int index) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
registerGroup() int
registerSlot({required FocusNode focusNode, required TextEditingController controller}) int
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
setValues(String values) → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited