ShadListSection class

A section in a ShadStickySectionList with a header widget and items.

Constructors

ShadListSection({required Widget header, required List<Widget> items})
A section in a ShadStickySectionList with a header widget and items.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
The header widget displayed at the top of this section.
final
items List<Widget>
The item widgets contained in this section.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited