header property

Widget header
final

The header widget displayed at the top of this section.

Rendered both inline (within the scrollable content) and as the sticky title pinned at the top of the viewport when this section is the active one.

Implementation

final Widget header;