ShadLocalizationsData$input$en class

Properties

copy String
en: 'Copy'
no setter
cut String
en: 'Cut'
no setter
hashCode int
The hash code for this object.
no setterinherited
paste String
en: 'Paste'
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectAll String
en: 'Select All'
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited