ShadOption<T> class

Inheritance
Available extensions

Constructors

ShadOption({Key? key, required T value, required Widget child, Color? hoveredBackgroundColor, EdgeInsetsGeometry? padding, Widget? selectedIcon, BorderRadius? radius, TextDirection? direction, Color? backgroundColor, Color? selectedBackgroundColor, TextStyle? textStyle, TextStyle? selectedTextStyle})
const

Properties

backgroundColor Color?
The background color of the ShadOption, defaults to ShadThemeData.optionTheme.backgroundColor.
final
child Widget
The child widget.
final
direction TextDirection?
The direction of the ambient.
final
hashCode int
The hash code for this object.
no setterinherited
hoveredBackgroundColor Color?
The background color of the ShadOption when hovered, defaults to ShadThemeData.accent.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsetsGeometry?
The padding of the ShadOption, defaults to EdgeInsets.symmetric(horizontal: 8, vertical: 6)
final
radius BorderRadius?
The radius of the ShadOption, defaults to ShadThemeData.radius.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedBackgroundColor Color?
The background color of the ShadOption when selected, defaults to ShadThemeData.optionTheme.selectedBackgroundColor.
final
selectedIcon Widget?
The icon of the ShadOption when selected.
final
selectedTextStyle TextStyle?
The text style of the ShadOption when selected, defaults to ShadThemeData.optionTheme.selectedTextStyle.
final
textStyle TextStyle?
The text style of the ShadOption, defaults to ShadThemeData.optionTheme.textStyle.
final
value → T
The value of the ShadOption, it must be unique above the options.
final

Methods

animate({Key? key, List<Effect>? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) Animate

Available on Widget, provided by the AnimateWidgetExtensions extension

Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex. myWidget.animate() is equivalent to Animate(child: myWidget).
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ShadOption<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
positionedWith(ShadPosition position) Widget

Available on Widget, provided by the PositionedExt extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited