ShadOptionTheme class

Annotations

Constructors

ShadOptionTheme({bool canMerge = true, Color? hoveredBackgroundColor, Color? selectedBackgroundColor, Color? backgroundColor, TextStyle? textStyle, TextStyle? selectedTextStyle, EdgeInsetsGeometry? padding, BorderRadius? radius, Color? selectedIconColor})
const

Properties

backgroundColor Color?
final
canMerge bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hoveredBackgroundColor Color?
final
padding EdgeInsetsGeometry?
final
radius BorderRadius?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedBackgroundColor Color?
final
selectedIconColor Color?
final
selectedTextStyle TextStyle?
final
textStyle TextStyle?
final

Methods

copyWith({Color? hoveredBackgroundColor, EdgeInsetsGeometry? padding, BorderRadius? radius, Color? backgroundColor, TextStyle? textStyle, Color? selectedBackgroundColor, TextStyle? selectedTextStyle, Color? selectedIconColor}) ShadOptionTheme
inherited
merge(ShadOptionTheme? other) ShadOptionTheme
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lerp(ShadOptionTheme? a, ShadOptionTheme? b, double t) ShadOptionTheme?