target property
The offset of the target the overlay is positioned near in the global coordinate system.
Implementation
final Offset target;
The offset of the target the overlay is positioned near in the global coordinate system.
final Offset target;