verticalOffset property
The amount of vertical distance between the target and the displayed overlay.
Implementation
final double verticalOffset;
The amount of vertical distance between the target and the displayed overlay.
final double verticalOffset;