ShadProgressTheme class
- Annotations
-
- @themeGen
- @immutable
Constructors
- ShadProgressTheme({bool canMerge = true, Color? backgroundColor, Color? color, BorderRadius? borderRadius, BorderRadius? innerBorderRadius, double? minHeight})
-
const
Properties
- backgroundColor → Color?
-
The background color of the progress bar.
Defaults to the theme's secondary color if not specified.
final
- borderRadius → BorderRadius?
-
The border radius of the progress bar's outer container.
Defaults to a circular radius of 16 if not specified.
final
- canMerge → bool
-
no setter
- color → Color?
-
The color of the progress indicator itself.
Defaults to the theme's primary color if not specified; overridden by
valueColorif set.final - hashCode → int
-
The hash code for this object.
no setterinherited
- innerBorderRadius → BorderRadius?
-
The border radius of the progress indicator itself.
Defaults to zero (sharp edges) if not specified.
final
- minHeight → double?
-
The minimum height of the progress bar.
Defaults to 16 if not specified.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Color? backgroundColor, Color? color, BorderRadius? borderRadius, BorderRadius? innerBorderRadius, double? minHeight}) → ShadProgressTheme -
inherited
-
merge(
ShadProgressTheme? other) → ShadProgressTheme -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
ShadProgressTheme? a, ShadProgressTheme? b, double t) → ShadProgressTheme?