notifyUpdate property
Whether to notify the update of the provider, defaults to false
Implementation
final bool Function(ShadProvider<T> oldWidget)? notifyUpdate;
Whether to notify the update of the provider, defaults to false
final bool Function(ShadProvider<T> oldWidget)? notifyUpdate;