ShadProviderIndex class

An immutable class that holds an index.

Used by ShadIndexProvider to provide the index to the child widget.

Annotations

Constructors

ShadProviderIndex(int index)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited