registerPanel method
This method adds a new panel to the controller and returns its index.
Implementation
int registerPanel(ShadPanelInfo info) {
panelsInfo.add(info);
defaultSizes.add(info.defaultSize);
return panelsInfo.length - 1;
}
This method adds a new panel to the controller and returns its index.
int registerPanel(ShadPanelInfo info) {
panelsInfo.add(info);
defaultSizes.add(info.defaultSize);
return panelsInfo.length - 1;
}