ShadResizablePanel class

A widget that represents a single resizable panel within a ShadResizablePanelGroup.

The ShadResizablePanel allows users to define a panel that can be resized dynamically. It requires an ID for uniqueness, a child widget to display, and size constraints to control the resizing behavior. This panel can be part of a larger group of panels that can be resized relative to each other.

Inheritance
Available extensions

Constructors

ShadResizablePanel({Key? key, required Object id, required Widget child, required double defaultSize, double minSize = 0.0, double maxSize = 1.0})
A widget that represents a single resizable panel within a ShadResizablePanelGroup.
const

Properties

child Widget
The child widget displayed within the panel. This can be any widget that represents the content of the panel.
final
defaultSize double
The default size of the panel when it is first displayed. This value must be between minSize and maxSize.
final
hashCode int
The hash code for this object.
no setterinherited
id Object
The unique identifier for the panel. This ID must be unique among all panels in the group to ensure proper management and resizing behavior.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxSize double
The maximum size the panel can be resized to. This value must be greater than or equal to 0.
final
minSize double
The minimum size the panel can be resized to. This value must be greater than or equal to 0.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

animate({Key? key, List<Effect>? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) Animate

Available on Widget, provided by the AnimateWidgetExtensions extension

Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex. myWidget.animate() is equivalent to Animate(child: myWidget).
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
positionedWith(ShadPosition position) Widget

Available on Widget, provided by the PositionedExt extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited