child property
The child widget displayed within the panel. This can be any widget that represents the content of the panel.
Implementation
final Widget child;
The child widget displayed within the panel. This can be any widget that represents the content of the panel.
final Widget child;