maxSize property
The maximum size the panel can be resized to. This value must be greater than or equal to 0.
Implementation
final double maxSize;
The maximum size the panel can be resized to. This value must be greater than or equal to 0.
final double maxSize;