minSize property
The minimum size the panel can be resized to. This value must be greater than or equal to 0.
Implementation
final double minSize;
The minimum size the panel can be resized to. This value must be greater than or equal to 0.
final double minSize;