controller property
The controller that manages the resizable panels. If not provided, a new controller will be created.
Implementation
final ShadResizableController? controller;
The controller that manages the resizable panels. If not provided, a new controller will be created.
final ShadResizableController? controller;