handleIcon property
A custom widget to use as the resize handle. If provided, this will be displayed instead of the default icon.
Implementation
final Widget? handleIcon;
A custom widget to use as the resize handle. If provided, this will be displayed instead of the default icon.
final Widget? handleIcon;