closeOnSelect property
Whether to automatically close the popover when an option is selected.
Defaults to true.
Implementation
final bool closeOnSelect;
Whether to automatically close the popover when an option is selected.
Defaults to true.
final bool closeOnSelect;