enabled property
Whether the ShadSelect is enabled.
When disabled, the select cannot be interacted with and visually appears
disabled. Defaults to true.
Implementation
final bool enabled;
Whether the ShadSelect is enabled.
When disabled, the select cannot be interacted with and visually appears
disabled. Defaults to true.
final bool enabled;