focusNode property
The focus node to control the focus state of the ShadSelect.
If null, a default FocusNode will be created internally.
Implementation
final FocusNode? focusNode;
The focus node to control the focus state of the ShadSelect.
If null, a default FocusNode will be created internally.
final FocusNode? focusNode;