onChanged property
The callback that is called when the value of the ShadSelect changes.
This is used for single selection ShadSelect variants.
Implementation
final ValueChanged<T?>? onChanged;
The callback that is called when the value of the ShadSelect changes.
This is used for single selection ShadSelect variants.
final ValueChanged<T?>? onChanged;