onMultipleChanged property
The callback that is called when the values of the ShadSelect changes. Called only the variant is ShadSelect.multiple.
Implementation
final ValueChanged<Set<T>>? onMultipleChanged;
The callback that is called when the values of the ShadSelect changes. Called only the variant is ShadSelect.multiple.
final ValueChanged<Set<T>>? onMultipleChanged;