onSearchSubmitted property
Callback function invoked when the search query is submitted in search-enabled ShadSelect variants. Provides the current search string as an argument.
Implementation
final ValueChanged<String>? onSearchSubmitted;
Callback function invoked when the search query is submitted in search-enabled ShadSelect variants. Provides the current search string as an argument.
final ValueChanged<String>? onSearchSubmitted;