options property

Iterable<Widget>? options
final

An iterable of widgets representing the selectable options.

Use this for a small, static set of options. For larger or dynamic lists, consider using optionsBuilder for better performance.

Each widget in this iterable should typically be a ShadOption widget.

Implementation

final Iterable<Widget>? options;