padding property
The padding around the content of the select input.
Defaults to EdgeInsets.symmetric(horizontal: 12, vertical: 8).
Implementation
final EdgeInsetsGeometry? padding;
The padding around the content of the select input.
Defaults to EdgeInsets.symmetric(horizontal: 12, vertical: 8).
final EdgeInsetsGeometry? padding;