popoverController property
Controller for managing the visibility and behavior of the popover.
If null, a default ShadPopoverController is created internally.
Implementation
final ShadPopoverController? popoverController;
Controller for managing the visibility and behavior of the popover.
If null, a default ShadPopoverController is created internally.
final ShadPopoverController? popoverController;