scrollController property
The scroll controller for the options list in the popover.
If null, a default ScrollController will be created internally.
Implementation
final ScrollController? scrollController;
The scroll controller for the options list in the popover.
If null, a default ScrollController will be created internally.
final ScrollController? scrollController;