ShadSelectTheme class

Annotations

Constructors

ShadSelectTheme({bool canMerge = true, ShadDecoration? decoration, TextStyle? placeholderStyle, double? minWidth, double? maxWidth, double? maxHeight, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? optionsPadding, bool? showScrollToTopChevron, bool? showScrollToBottomChevron, ShadAnchorBase? anchor, EdgeInsetsGeometry? searchPadding, bool? clearSearchOnClose, List<Effect>? effects, List<BoxShadow>? shadows, ImageFilter? filter, Duration? popoverReverseDuration})
const

Properties

anchor ShadAnchorBase?
The anchor configuration for positioning the popover relative to the select input.
final
canMerge bool
no setter
clearSearchOnClose bool?
Whether to clear the search input when the popover is closed.
final
decoration ShadDecoration?
The visual decoration of the select input.
final
effects List<Effect>?
The animation effects applied to the popover. Defaults to FadeEffect(), ScaleEffect(begin: Offset(.95, .95), end: Offset(1, 1)), MoveEffect(begin: Offset(0, 2), end: Offset(0, 0)).
final
filter ImageFilter?
The filter of the popover. If null, falls back to ShadPopoverTheme.
final
hashCode int
The hash code for this object.
no setterinherited
maxHeight double?
The maximum height of the select popover.
final
maxWidth double?
The maximum width of the select input and popover.
final
minWidth double?
The minimum width of the select input and popover.
final
optionsPadding EdgeInsetsGeometry?
The padding around the options within the popover.
final
padding EdgeInsetsGeometry?
The padding around the content of the select input.
final
placeholderStyle TextStyle?
The text style to apply by default to the placeholder widget. If the placeholder contains a Text widget, this style will be merged with its existing style.
final
popoverReverseDuration Duration?
The duration of the popover's exit animation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchPadding EdgeInsetsGeometry?
Padding around the search input field.
final
shadows List<BoxShadow>?
The shadows applied to the popover, defaults to ShadShadows.md.
final
showScrollToBottomChevron bool?
Whether to display a chevron icon at the bottom of the popover when scrollable. Defaults to true.
final
showScrollToTopChevron bool?
Whether to display a chevron icon at the top of the popover when scrollable. Defaults to true.
final

Methods

copyWith({Duration? popoverReverseDuration, ShadDecoration? decoration, TextStyle? placeholderStyle, double? minWidth, double? maxWidth, double? maxHeight, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? optionsPadding, bool? showScrollToTopChevron, bool? showScrollToBottomChevron, ShadAnchorBase? anchor, EdgeInsetsGeometry? searchPadding, bool? clearSearchOnClose, ImageFilter? filter, List<Effect>? effects, List<BoxShadow>? shadows}) ShadSelectTheme
inherited
merge(ShadSelectTheme? other) ShadSelectTheme
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lerp(ShadSelectTheme? a, ShadSelectTheme? b, double t) ShadSelectTheme?