ShadShadows class abstract

Constructors

ShadShadows()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

inner → const List<BoxShadow>
lg → const List<BoxShadow>
md → const List<BoxShadow>
regular → const List<BoxShadow>
sm → const List<BoxShadow>
xl → const List<BoxShadow>
xl2 → const List<BoxShadow>