closeProgressThreshold property
The threshold for determining whether the sheet is closing.
Defaults to 0.5.
Implementation
final double? closeProgressThreshold;
The threshold for determining whether the sheet is closing.
Defaults to 0.5.
final double? closeProgressThreshold;