controller property
A controller for the ShadSlider widget, managing its value.
Extends ValueNotifier to provide reactive updates when the slider value changes.
Implementation
final ShadSliderController? controller;
A controller for the ShadSlider widget, managing its value.
Extends ValueNotifier to provide reactive updates when the slider value changes.
final ShadSliderController? controller;