disabledActiveTrackColor property
The color of the active track when the slider is disabled.
Defaults to a semi-transparent version of the theme's primary color.
Implementation
final Color? disabledActiveTrackColor;
The color of the active track when the slider is disabled.
Defaults to a semi-transparent version of the theme's primary color.
final Color? disabledActiveTrackColor;