disabledInactiveTrackColor property
The color of the inactive track when the slider is disabled.
Defaults to a semi-transparent version of the theme's secondary color.
Implementation
final Color? disabledInactiveTrackColor;
The color of the inactive track when the slider is disabled.
Defaults to a semi-transparent version of the theme's secondary color.
final Color? disabledInactiveTrackColor;