initialValue property
The initial value of the slider.
This value is used only when controller is null.
Implementation
final double? initialValue;
The initial value of the slider.
This value is used only when controller is null.
final double? initialValue;