mouseCursor property
The cursor for the slider when it is enabled.
Defaults to SystemMouseCursors.click.
Implementation
final MouseCursor? mouseCursor;
The cursor for the slider when it is enabled.
Defaults to SystemMouseCursors.click.
final MouseCursor? mouseCursor;