thumbBorderColor property
The border color of the slider thumb when enabled.
Defaults to the theme's primary color.
Implementation
final Color? thumbBorderColor;
The border color of the slider thumb when enabled.
Defaults to the theme's primary color.
final Color? thumbBorderColor;