headerPadding property
Padding inside the sticky header pinned at the top.
Defaults to EdgeInsets.fromLTRB(24, 20, 24, 12).
Implementation
final EdgeInsetsGeometry? headerPadding;
Padding inside the sticky header pinned at the top.
Defaults to EdgeInsets.fromLTRB(24, 20, 24, 12).
final EdgeInsetsGeometry? headerPadding;