ShadStickySectionListTheme class

Annotations

Constructors

ShadStickySectionListTheme({bool canMerge = true, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? headerPadding, Color? headerBackgroundColor, ShadBorder? headerBorder, AlignmentGeometry? headerAlignment, EdgeInsetsGeometry? inlineHeaderPadding, Color? inlineHeaderBackgroundColor, Clip? clipBehavior})
const

Properties

canMerge bool
no setter
clipBehavior Clip?
final
hashCode int
The hash code for this object.
no setterinherited
headerAlignment AlignmentGeometry?
Alignment of the header content within the sticky header bar. Defaults to Alignment.centerLeft.
final
headerBackgroundColor Color?
Background color of the sticky header. Defaults to the theme's background color.
final
headerBorder ShadBorder?
Border surrounding the sticky header. Defaults to a bottom border using the theme's border color.
final
headerPadding EdgeInsetsGeometry?
Padding inside the sticky header pinned at the top. Defaults to EdgeInsets.fromLTRB(24, 20, 24, 12).
final
inlineHeaderBackgroundColor Color?
Background color of the inline section headers. Defaults to the theme's muted color at 30% alpha.
final
inlineHeaderPadding EdgeInsetsGeometry?
Padding inside the inline section headers within the scroll content. Defaults to EdgeInsets.symmetric(horizontal: 24, vertical: 12).
final
padding EdgeInsetsGeometry?
Padding around the entire scrollable content. Defaults to EdgeInsets.zero.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({EdgeInsetsGeometry? padding, EdgeInsetsGeometry? headerPadding, Color? headerBackgroundColor, ShadBorder? headerBorder, AlignmentGeometry? headerAlignment, EdgeInsetsGeometry? inlineHeaderPadding, Color? inlineHeaderBackgroundColor, Clip? clipBehavior}) ShadStickySectionListTheme
inherited
merge(ShadStickySectionListTheme? other) ShadStickySectionListTheme
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited