checkedTrackColor property
Color of the track when the switch is in the checked (on) state.
Defaults to the theme's primary color.
Implementation
final Color? checkedTrackColor;
Color of the track when the switch is in the checked (on) state.
Defaults to the theme's primary color.
final Color? checkedTrackColor;