enabled property
Whether the switch is enabled and can be interacted with.
Defaults to true. When disabled, it visually indicates it's inactive and ignores user interactions.
Implementation
final bool enabled;
Whether the switch is enabled and can be interacted with.
Defaults to true. When disabled, it visually indicates it's inactive and ignores user interactions.
final bool enabled;