uncheckedTrackColor property
Color of the track when the switch is in the unchecked (off) state.
Defaults to the theme's input color.
Implementation
final Color? uncheckedTrackColor;
Color of the track when the switch is in the unchecked (off) state.
Defaults to the theme's input color.
final Color? uncheckedTrackColor;