value property
T
value
final
The value associated with this tab, used for selection and identification.
Implementation
final T value;
The value associated with this tab, used for selection and identification.
final T value;