ShadTable constructor
const
ShadTable({
- Key? key,
- required ShadTableCellBuilder builder,
- required int columnCount,
- required int rowCount,
- ShadTableCell header(
- BuildContext context,
- int column
- TableSpanBuilder? columnBuilder,
- TableSpanBuilder? rowBuilder,
- TableSpanExtent? rowSpanExtent(
- int row
- TableSpanExtent? columnSpanExtent(
- int row
- TableSpanDecoration? rowSpanBackgroundDecoration(
- int row
- TableSpanDecoration? rowSpanForegroundDecoration(
- int row
- TableSpanDecoration? columnSpanBackgroundDecoration(
- int row
- TableSpanDecoration? columnSpanForegroundDecoration(
- int row
- ValueChanged<
int?> ? onHoveredRowIndex, - ScrollController? horizontalScrollController,
- ScrollController? verticalScrollController,
- int? pinnedRowCount,
- int? pinnedColumnCount,
- bool? primary,
- DiagonalDragBehavior? diagonalDragBehavior,
- DragStartBehavior? dragStartBehavior,
- ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior,
- ScrollPhysics? verticalScrollPhysics,
- ScrollPhysics? horizontalScrollPhysics,
- void onRowTap(
- int row
- void onColumnTap(
- int row
- Set<
PointerDeviceKind> ? supportedDevices, - void onRowTapDown(
- int row
- void onRowTapUp(
- int row
- void onRowTapCancel(
- int row
- void onRowSecondaryTap(
- int row
- void onRowSecondaryTapDown(
- int row
- void onRowSecondaryTapUp(
- int row
- void onRowSecondaryTapCancel(
- int row
- void onColumnTapDown(
- int row
- void onColumnTapUp(
- int row
- void onColumnTapCancel(
- int row
- void onColumnSecondaryTap(
- int row
- void onColumnSecondaryTapDown(
- int row
- void onColumnSecondaryTapUp(
- int row
- void onColumnSecondaryTapCancel(
- int row
Creates a ShadTable of widgets that are created on demand.
This constructor is appropriate for table views with a large
number of cells because the builder is called only for those
cells that are actually visible.
Implementation
const ShadTable({
super.key,
required ShadTableCellBuilder this.builder,
required this.columnCount,
required this.rowCount,
ShadTableCell Function(BuildContext context, int column)? header,
ShadTableCell Function(BuildContext context, int column)? footer,
this.columnBuilder,
this.rowBuilder,
this.rowSpanExtent,
this.columnSpanExtent,
this.rowSpanBackgroundDecoration,
this.rowSpanForegroundDecoration,
this.columnSpanBackgroundDecoration,
this.columnSpanForegroundDecoration,
this.onHoveredRowIndex,
this.horizontalScrollController,
this.verticalScrollController,
this.pinnedRowCount,
this.pinnedColumnCount,
this.primary,
this.diagonalDragBehavior,
this.dragStartBehavior,
this.keyboardDismissBehavior,
this.verticalScrollPhysics,
this.horizontalScrollPhysics,
this.onRowTap,
this.onColumnTap,
this.supportedDevices,
this.onRowTapDown,
this.onRowTapUp,
this.onRowTapCancel,
this.onRowSecondaryTap,
this.onRowSecondaryTapDown,
this.onRowSecondaryTapUp,
this.onRowSecondaryTapCancel,
this.onColumnTapDown,
this.onColumnTapUp,
this.onColumnTapCancel,
this.onColumnSecondaryTap,
this.onColumnSecondaryTapDown,
this.onColumnSecondaryTapUp,
this.onColumnSecondaryTapCancel,
}) : children = null,
headerBuilder = header,
footerBuilder = footer,
header = null,
footer = null;