ShadTableTheme class

Annotations

Constructors

ShadTableTheme({bool canMerge = true, DiagonalDragBehavior? diagonalDragBehavior, DragStartBehavior? dragStartBehavior, ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior, TableSpanBuilder? columnBuilder, TableSpanBuilder? rowBuilder, Alignment? cellAlignment, double? cellHeight, EdgeInsetsGeometry? cellPadding, TextStyle? cellStyle, TextStyle? cellHeaderStyle, TextStyle? cellFooterStyle})
const

Properties

canMerge bool
no setter
cellAlignment Alignment?
final
cellFooterStyle TextStyle?
final
cellHeaderStyle TextStyle?
final
cellHeight double?
final
cellPadding EdgeInsetsGeometry?
final
cellStyle TextStyle?
final
columnBuilder TableSpanBuilder?
Builder for defining column properties.
final
diagonalDragBehavior DiagonalDragBehavior?
Drag behavior when dragging diagonally.
final
dragStartBehavior DragStartBehavior?
Determines when a drag formally starts.
final
hashCode int
The hash code for this object.
no setterinherited
keyboardDismissBehavior ScrollViewKeyboardDismissBehavior?
Configures how the keyboard is dismissed when a drag starts.
final
rowBuilder TableSpanBuilder?
Builder for defining row properties.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({DiagonalDragBehavior? diagonalDragBehavior, DragStartBehavior? dragStartBehavior, ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior, Span? columnBuilder(int)?, Span? rowBuilder(int)?, Alignment? cellAlignment, double? cellHeight, EdgeInsetsGeometry? cellPadding, TextStyle? cellHeaderStyle, TextStyle? cellStyle, TextStyle? cellFooterStyle}) ShadTableTheme
inherited
merge(ShadTableTheme? other) ShadTableTheme
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lerp(ShadTableTheme? a, ShadTableTheme? b, double t) ShadTableTheme?