ShadTextDefaultTheme class abstract

Constructors

ShadTextDefaultTheme()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

blockquote({required String family}) TextStyle
h1({required String family}) TextStyle
h1Large({required String family}) TextStyle
h2({required String family}) TextStyle
h3({required String family}) TextStyle
h4({required String family}) TextStyle
large({required String family}) TextStyle
lead({required String family}) TextStyle
list({required String family}) TextStyle
muted({required String family}) TextStyle
p({required String family}) TextStyle
small({required String family}) TextStyle
table({required String family}) TextStyle