ShadTextTheme class

Annotations

Constructors

ShadTextTheme({TextStyle? h1Large, TextStyle? h1, TextStyle? h2, TextStyle? h3, TextStyle? h4, TextStyle? p, TextStyle? blockquote, TextStyle? table, TextStyle? list, TextStyle? lead, TextStyle? large, TextStyle? small, TextStyle? muted, String? family, String? package, GoogleFontBuilder? googleFontBuilder, Map<String, TextStyle> custom = const {}})
factory
ShadTextTheme.custom({bool canMerge = true, required TextStyle h1Large, required TextStyle h1, required TextStyle h2, required TextStyle h3, required TextStyle h4, required TextStyle p, required TextStyle blockquote, required TextStyle table, required TextStyle list, required TextStyle lead, required TextStyle large, required TextStyle small, required TextStyle muted, required String family, Map<String, TextStyle> custom = const {}, GoogleFontBuilder? googleFontBuilder})
const
ShadTextTheme.fromGoogleFont(GoogleFontBuilder fontBuilder, {ShadTextTheme? textTheme, Map<String, TextStyle> custom = const {}})
factory

Properties

blockquote TextStyle
final
canMerge bool
final
custom Map<String, TextStyle>
final
family String
The font family of the theme.
final
googleFontBuilder GoogleFontBuilder?
final
h1 TextStyle
final
h1Large TextStyle
final
h2 TextStyle
final
h3 TextStyle
final
h4 TextStyle
final
hashCode int
The hash code for this object.
no setteroverride
large TextStyle
final
lead TextStyle
final
list TextStyle
final
muted TextStyle
final
p TextStyle
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
small TextStyle
final
table TextStyle
final

Methods

apply({String? family, List<String>? fontFamilyFallback, String? package, double fontSizeFactor = 1.0, double fontSizeDelta = 0.0, Color? displayColor, Color? bodyColor, Color? decorationColor, TextDecoration? decoration, TextDecorationStyle? decorationStyle}) ShadTextTheme
copyWith({TextStyle? h1Large, TextStyle? h1, TextStyle? h2, TextStyle? h3, TextStyle? h4, TextStyle? p, TextStyle? blockquote, TextStyle? table, TextStyle? list, TextStyle? lead, TextStyle? large, TextStyle? small, TextStyle? muted, String? family, String? package, GoogleFontBuilder? googleFontBuilder, Map<String, TextStyle>? custom}) ShadTextTheme
merge(ShadTextTheme? other) ShadTextTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

lerp(ShadTextTheme? a, ShadTextTheme? b, double t) ShadTextTheme?