controller property
Controls the text being edited. If null, an internal controller is created and initialized with initialValue.
Implementation
final TextEditingController? controller;
Controls the text being edited. If null, an internal controller is created and initialized with initialValue.
final TextEditingController? controller;