selectionHeightStyle property
Style used to calculate height of text selection highlight.
Implementation
final ui.BoxHeightStyle selectionHeightStyle;
Style used to calculate height of text selection highlight.
final ui.BoxHeightStyle selectionHeightStyle;