selectionWidthStyle property
Style used to calculate width of text selection highlight.
Implementation
final ui.BoxWidthStyle selectionWidthStyle;
Style used to calculate width of text selection highlight.
final ui.BoxWidthStyle selectionWidthStyle;