ShadTextareaTheme class

Annotations

Constructors

ShadTextareaTheme({bool canMerge = true, ShadDecoration? decoration, EdgeInsetsGeometry? padding, TextStyle? style, TextStyle? placeholderStyle, AlignmentGeometry? placeholderAlignment, EdgeInsetsGeometry? inputPadding, MainAxisAlignment? mainAxisAlignment, CrossAxisAlignment? crossAxisAlignment, double? gap, BoxConstraints? constraints, double? minHeight, double? maxHeight, bool? resizable, WidgetBuilder? resizeHandleBuilder, EdgeInsetsGeometry? scrollbarPadding})
const

Properties

canMerge bool
no setter
constraints BoxConstraints?
Constraints to control layout of the field (e.g. minHeight).
final
crossAxisAlignment CrossAxisAlignment?
Layout alignment along the vertical axis of the row.
final
decoration ShadDecoration?
Optional visual decoration for the textarea. Merged with the theme’s default decoration if provided.
final
gap double?
Horizontal spacing between text and any leading/trailing elements.
final
hashCode int
The hash code for this object.
no setterinherited
inputPadding EdgeInsetsGeometry?
Inner padding between text and decoration inside the textarea.
final
mainAxisAlignment MainAxisAlignment?
Layout alignment along the horizontal axis (e.g. leading, text, trailing).
final
maxHeight double?
The maximum height of the textarea (default is 500).
final
minHeight double?
The minimum height of the textarea (default is 80).
final
padding EdgeInsetsGeometry?
Padding around the field. This is outer padding including borders and input.
final
placeholderAlignment AlignmentGeometry?
Alignment for the placeholder inside the field.
final
placeholderStyle TextStyle?
The text style to use for the placeholder. If not specified, uses the theme's muted style.
final
resizable bool?
Whether the textarea can be resized by the user (default is true).
final
resizeHandleBuilder WidgetBuilder?
Allows customizing the resize handle (shown at bottom-right).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollbarPadding EdgeInsetsGeometry?
The padding around the scrollbar.
final
style TextStyle?
The text style used for the input text inside the textarea.
final

Methods

copyWith({ShadDecoration? decoration, EdgeInsetsGeometry? padding, TextStyle? style, TextStyle? placeholderStyle, AlignmentGeometry? placeholderAlignment, EdgeInsetsGeometry? inputPadding, MainAxisAlignment? mainAxisAlignment, CrossAxisAlignment? crossAxisAlignment, double? gap, BoxConstraints? constraints, double? minHeight, double? maxHeight, bool? resizable, Widget resizeHandleBuilder(BuildContext)?, EdgeInsetsGeometry? scrollbarPadding}) ShadTextareaTheme
inherited
merge(ShadTextareaTheme? other) ShadTextareaTheme
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited