ShadThemeDataTween class

An interpolation between two ShadThemeDatas.

This class specializes the interpolation of Tween<ShadThemeData> to call the ShadThemeData.lerp method.

See Tween for a discussion on how to use interpolation objects.

Inheritance

Constructors

ShadThemeDataTween({ShadThemeData? begin, ShadThemeData? end})
Creates a ShadThemeData tween.

Properties

begin ShadThemeData?
The value this variable has at the beginning of the animation.
getter/setter pairinherited
end ShadThemeData?
The value this variable has at the end of the animation.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

animate(Animation<double> parent) Animation<ShadThemeData>
Returns a new Animation that is driven by the given animation but that takes on values determined by this object.
inherited
chain(Animatable<double> parent) Animatable<ShadThemeData>
Returns a new Animatable whose value is determined by first evaluating the given parent and then evaluating this object at the result.
inherited
evaluate(Animation<double> animation) ShadThemeData
The current value of this object for the given Animation.
inherited
lerp(double t) ShadThemeData
Returns the value this variable has at the given animation clock value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transform(double t) ShadThemeData
Returns the interpolated value for the current value of the given animation.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited