initialDayPeriod property
The initial day period to show in the picker, defaults to
ShadDayPeriod.am.
Implementation
final ShadDayPeriod? initialDayPeriod;
The initial day period to show in the picker, defaults to
ShadDayPeriod.am.
final ShadDayPeriod? initialDayPeriod;