secondPlaceholder property
The widget to display as the placeholder for the second field, defaults to
Text('00').
Implementation
final Widget? secondPlaceholder;
The widget to display as the placeholder for the second field, defaults to
Text('00').
final Widget? secondPlaceholder;