ShadTimePickerController class

A controller for ShadTimePicker to manage the selected time.

Extends ChangeNotifier to provide reactive updates when the selected time changes.

Inheritance

Constructors

ShadTimePickerController({int? hour, int? minute, int? second, ShadDayPeriod? period})
Creates a ShadTimePickerController.
ShadTimePickerController.fromTimeOfDay(ShadTimeOfDay? timeOfDay)
Creates a ShadTimePickerController initialized with a ShadTimeOfDay object.

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hour int?
The selected hour.
getter/setter pair
minute int?
The selected minute.
getter/setter pair
period ShadDayPeriod?
The selected day period (AM/PM).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
second int?
The selected second.
getter/setter pair
value ShadTimeOfDay?
Returns the current ShadTimeOfDay value from the controller.
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setDayPeriod(ShadDayPeriod? period) → void
Sets the day period (AM/PM) and notifies listeners.
setHour(int? hour) → void
Sets the hour and notifies listeners.
setMinute(int? minute) → void
Sets the minute and notifies listeners.
setSecond(int? second) → void
Sets the second and notifies listeners.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited