ShadTimePickerField class

A single input field for ShadTimePicker, used for hour, minute, or second input.

Inheritance
Available extensions

Constructors

ShadTimePickerField({Key? key, Widget? label, Widget? placeholder, ShadTimePickerTextEditingController? controller, double? gap, TextStyle? style, TextStyle? labelStyle, ValueChanged<String>? onChanged, FocusNode? focusNode, double? width, EdgeInsetsGeometry? padding, ShadDecoration? decoration, bool enabled = true, WidgetBuilder? keyboardToolbarBuilder})
A single input field for ShadTimePicker, used for hour, minute, or second input.
const

Properties

controller ShadTimePickerTextEditingController?
The text editing controller for the input field.
final
decoration ShadDecoration?
The visual decoration of the input field.
final
enabled bool
Whether the input field is enabled.
final
focusNode FocusNode?
Focus node to control the focus state of the input field.
final
gap double?
The vertical gap between the label and the input field.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardToolbarBuilder WidgetBuilder?
A builder function that returns the toolbar widget.
final
label Widget?
The label widget to display above the input field.
final
labelStyle TextStyle?
The text style for the label widget.
final
onChanged ValueChanged<String>?
Callback function invoked when the text in the input field changes.
final
padding EdgeInsetsGeometry?
Padding around the input field's content area.
final
placeholder Widget?
The placeholder widget to display when the input field is empty.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
The text style for the input field's text.
final
width double?
The width of the input field.
final

Methods

animate({Key? key, List<Effect>? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) Animate

Available on Widget, provided by the AnimateWidgetExtensions extension

Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex. myWidget.animate() is equivalent to Animate(child: myWidget).
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ShadTimePickerField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
positionedWith(ShadPosition position) Widget

Available on Widget, provided by the PositionedExt extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited