enabled property
Whether the input field is enabled.
When disabled, the field cannot be interacted with and visually appears
disabled. Defaults to true.
Implementation
final bool enabled;
Whether the input field is enabled.
When disabled, the field cannot be interacted with and visually appears
disabled. Defaults to true.
final bool enabled;