onChanged property
Callback function invoked when the text in the input field changes.
Provides the current text value as an argument.
Implementation
final ValueChanged<String>? onChanged;
Callback function invoked when the text in the input field changes.
Provides the current text value as an argument.
final ValueChanged<String>? onChanged;