ShadTimePickerTextEditingController class

Custom TextEditingController for ShadTimePickerField to handle time input formatting and validation.

Inheritance

Constructors

ShadTimePickerTextEditingController({String? text, TextStyle? placeholderStyle, int min = 0, int max = 59})
Creates a ShadTimePickerTextEditingController.
ShadTimePickerTextEditingController.fromValue(TextEditingValue? value, {TextStyle? placeholderStyle, int min = 0, int max = 59})
Creates a ShadTimePickerTextEditingController from a TextEditingValue.

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
max int
Maximum allowed value for the input field.
final
min int
Minimum allowed value for the input field.
final
placeholderStyle TextStyle?
The style of the placeholder text.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection TextSelection
The currently selected range within text.
getter/setter pairinherited
text String
The current string the user is editing.
getter/setter pairinherited-getteroverride-setter
value TextEditingValue
The current value stored in this notifier.
getter/setter pairinherited-getteroverride-setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
adjustText(String newText) String
buildTextSpan({required BuildContext context, TextStyle? style, required bool withComposing}) TextSpan
Builds TextSpan from current editing value.
override
clear() → void
Set the value to empty.
inherited
clearComposing() → void
Set the composing region to an empty range.
inherited
copyWith({String? text, int? min, int? max, TextStyle? placeholderStyle}) ShadTimePickerTextEditingController
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited