value property
The current value stored in this notifier.
When the value is replaced with something that is not equal to the old value as evaluated by the equality operator ==, this class notifies its listeners.
Implementation
@override
T get value => _value;
Implementation
@override
set value(TextEditingValue newValue) {
assert(
!newValue.composing.isValid || newValue.isComposingRangeValid,
'New TextEditingValue $newValue has an invalid non-empty composing range '
'${newValue.composing}. It is recommended to use a valid composing range,'
' even for readonly text fields.',
);
final newText = adjustText(newValue.text);
// super.value = newValue;
super.value = TextEditingValue(
text: adjustText(newValue.text),
selection: TextSelection.collapsed(offset: newText.length),
);
}