builder property
The builder function that creates the tooltip content widget.
Called with the BuildContext to build the tooltip's content.
Implementation
final WidgetBuilder builder;
The builder function that creates the tooltip content widget.
Called with the BuildContext to build the tooltip's content.
final WidgetBuilder builder;