controller property

ShadTooltipController? controller
final

The controller that manages the visibility of the ShadTooltip.

Allows programmatic control over showing and hiding the tooltip. If null, a default ShadTooltipController is created internally.

Implementation

final ShadTooltipController? controller;