focusNode property
The focus node of the child widget.
When the child gains focus, the tooltip will be shown.
Implementation
final FocusNode? focusNode;
The focus node of the child widget.
When the child gains focus, the tooltip will be shown.
final FocusNode? focusNode;