hoverStrategies property
The hover strategies to use for the tooltip on devices with touchscreens.
Configures how hover interactions are interpreted, especially on touch devices.
Implementation
final ShadHoverStrategies? hoverStrategies;
The hover strategies to use for the tooltip on devices with touchscreens.
Configures how hover interactions are interpreted, especially on touch devices.
final ShadHoverStrategies? hoverStrategies;