ShadTooltipTheme class
- Annotations
-
- @themeGen
- @immutable
Constructors
-
ShadTooltipTheme({bool canMerge = true, Duration? waitDuration, Duration? showDuration, List<
Effect> ? effects, EdgeInsetsGeometry? padding, ShadDecoration? decoration, ShadAnchorBase? anchor, ShadHoverStrategies? hoverStrategies, Duration? longPressDuration, Duration? duration, Duration? reverseDuration}) -
const
Properties
- anchor → ShadAnchorBase?
-
The anchor position of the tooltip relative to its child.
final
- canMerge → bool
-
no setter
- decoration → ShadDecoration?
-
The decoration of the tooltip.
final
- duration → Duration?
-
The duration of the tooltip's entrance animation.
final
-
effects
→ List<
Effect> ? -
The animation effects applied to the tooltip.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoverStrategies → ShadHoverStrategies?
-
The hover strategies to use for the tooltip on devices with touchscreens.
final
- longPressDuration → Duration?
-
The duration for a long press to be recognized, triggering the tooltip on
touch devices.
final
- padding → EdgeInsetsGeometry?
-
The padding of the tooltip content.
final
- reverseDuration → Duration?
-
The duration of the tooltip's exit animation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showDuration → Duration?
-
The length of time that the tooltip will be shown after a mouse pointer
exits the widget.
final
- waitDuration → Duration?
-
The length of time that a pointer must hover over a tooltip's widget
before the tooltip will be shown.
final
Methods
-
copyWith(
{Duration? waitDuration, Duration? showDuration, List< Effect> ? effects, ShadAnchorBase? anchor, EdgeInsetsGeometry? padding, ShadDecoration? decoration, ShadHoverStrategies? hoverStrategies, Duration? longPressDuration, Duration? duration, Duration? reverseDuration}) → ShadTooltipTheme -
inherited
-
merge(
ShadTooltipTheme? other) → ShadTooltipTheme -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
ShadTooltipTheme? a, ShadTooltipTheme? b, double t) → ShadTooltipTheme?