ShadVioletColorScheme class

Inheritance
Annotations

Constructors

ShadVioletColorScheme({required Color background, required Color foreground, required Color card, required Color cardForeground, required Color popover, required Color popoverForeground, required Color primary, required Color primaryForeground, required Color secondary, required Color secondaryForeground, required Color muted, required Color mutedForeground, required Color accent, required Color accentForeground, required Color destructive, required Color destructiveForeground, required Color border, required Color input, required Color ring, required Color selection, Map<String, Color> custom = const {}})
const
ShadVioletColorScheme.dark({Color background = const Color(0xff030712), Color foreground = const Color(0xfff9fafb), Color card = const Color(0xff030712), Color cardForeground = const Color(0xfff9fafb), Color popover = const Color(0xff030712), Color popoverForeground = const Color(0xfff9fafb), Color primary = const Color(0xff6d28d9), Color primaryForeground = const Color(0xfff9fafb), Color secondary = const Color(0xff1f2937), Color secondaryForeground = const Color(0xfff9fafb), Color muted = const Color(0xff1f2937), Color mutedForeground = const Color(0xff9ca3af), Color accent = const Color(0xff1f2937), Color accentForeground = const Color(0xfff9fafb), Color destructive = const Color(0xffef4444), Color destructiveForeground = const Color(0xfff9fafb), Color border = const Color(0xff1f2937), Color input = const Color(0xff1f2937), Color ring = const Color(0xff6d28d9), Color selection = const Color(0xFF355172), Map<String, Color> custom = const {}})
const
ShadVioletColorScheme.light({Color background = const Color(0xffffffff), Color foreground = const Color(0xff030712), Color card = const Color(0xffffffff), Color cardForeground = const Color(0xff030712), Color popover = const Color(0xffffffff), Color popoverForeground = const Color(0xff030712), Color primary = const Color(0xff7c3aed), Color primaryForeground = const Color(0xfff9fafb), Color secondary = const Color(0xfff3f4f6), Color secondaryForeground = const Color(0xff111827), Color muted = const Color(0xfff3f4f6), Color mutedForeground = const Color(0xff6b7280), Color accent = const Color(0xfff3f4f6), Color accentForeground = const Color(0xff111827), Color destructive = const Color(0xffef4444), Color destructiveForeground = const Color(0xfff9fafb), Color border = const Color(0xffe5e7eb), Color input = const Color(0xffe5e7eb), Color ring = const Color(0xff7c3aed), Color selection = const Color(0xFFB4D7FF), Map<String, Color> custom = const {}})
const

Properties

accent Color
finalinherited
accentForeground Color
finalinherited
background Color
finalinherited
border Color
finalinherited
canMerge bool
no setterinherited
card Color
finalinherited
cardForeground Color
finalinherited
custom Map<String, Color>
finalinherited
destructive Color
finalinherited
destructiveForeground Color
finalinherited
foreground Color
finalinherited
hashCode int
The hash code for this object.
no setterinherited
input Color
finalinherited
muted Color
finalinherited
mutedForeground Color
finalinherited
popover Color
finalinherited
popoverForeground Color
finalinherited
primary Color
finalinherited
primaryForeground Color
finalinherited
ring Color
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Color
finalinherited
secondaryForeground Color
finalinherited
selection Color
finalinherited

Methods

copyWith({Color? background, Color? foreground, Color? card, Color? cardForeground, Color? popover, Color? popoverForeground, Color? primary, Color? primaryForeground, Color? secondary, Color? secondaryForeground, Color? muted, Color? mutedForeground, Color? accent, Color? accentForeground, Color? destructive, Color? destructiveForeground, Color? border, Color? input, Color? ring, Color? selection, Map<String, Color>? custom}) ShadColorScheme
Creates a copy of this ShadColorScheme but with the given fields replaced with the new values.
inherited
merge(ShadColorScheme? other) ShadColorScheme
Merges this ShadColorScheme with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited