layout method

SliverGeometry layout()

Override this method to lay out children and return the final geometry of the boxy.

This method should call BoxyChild.layout for each child. It should also specify the position of each child with BaseBoxyChild.position.

Implementation

SliverGeometry layout() {
  return SliverGeometry.zero;
}