trailingPinnedColumnCount property
The number of columns that are permanently shown on the trailing vertical edge of the viewport.
If scrolling is enabled, other columns will scroll underneath the pinned columns.
Just like for regular columns, buildColumn method will be consulted for
additional information about the pinned column. The indices of trailing
pinned columns start at columnCount - trailingPinnedColumnCount and go
to columnCount - 1.
columnCount must not be null if trailingPinnedColumnCount is greater than zero.
The integer returned by this getter must be smaller than (or equal to) the integer returned by columnCount.
If the value returned by this getter changes throughout the lifetime of the delegate object, notifyListeners must be called.
Implementation
@override
int get trailingPinnedColumnCount => _trailingPinnedColumnCount;
set
trailingPinnedColumnCount
(int value)
Implementation
set trailingPinnedColumnCount(int value) {
assert(value >= 0);
assert(pinnedColumnCount + value <= columnCount);
if (trailingPinnedColumnCount == value) {
return;
}
_trailingPinnedColumnCount = value;
notifyListeners();
}