trailingPinnedRowCount property

  1. @override
int get trailingPinnedRowCount
override

The number of rows that are permanently shown on the trailing horizontal edge of the viewport.

If scrolling is enabled, other rows will scroll underneath the pinned rows.

Just like for regular rows, buildRow will be consulted for additional information about the pinned row. The indices of trailing pinned rows start at rowCount - trailingPinnedRowCount and go to rowCount - 1.

rowCount must not be null if trailingPinnedRowCount is greater than zero.

The integer returned by this getter must be smaller than (or equal to) the integer returned by rowCount.

If the value returned by this getter changes throughout the lifetime of the delegate object, notifyListeners must be called.

Implementation

@override
int get trailingPinnedRowCount => _trailingPinnedRowCount;
set trailingPinnedRowCount (int value)

Implementation

set trailingPinnedRowCount(int value) {
  assert(value >= 0);
  assert(pinnedRowCount + value <= rowCount);
  if (trailingPinnedRowCount == value) {
    return;
  }
  _trailingPinnedRowCount = value;
  notifyListeners();
}