alignment property
The alignment of the table within the viewport when there is extra space.
Defaults to Alignment.topLeft.
Implementation
final AlignmentGeometry alignment;
The alignment of the table within the viewport when there is extra space.
Defaults to Alignment.topLeft.
final AlignmentGeometry alignment;