delegate property
A delegate that provides the children for the TwoDimensionalScrollView.
Implementation
final TableCellDelegateMixin delegate;
A delegate that provides the children for the TwoDimensionalScrollView.
final TableCellDelegateMixin delegate;