TableViewCell class
Creates a cell of the TableView, along with information regarding merged cells and RepaintBoundarys.
When merging cells in a TableView, the same child with the same merge
information must be returned from every vicinity the merged cell contains.
The build method will only be called once for a merged cell, but since
the table's children are lazily laid out, returning the same child and merge
information ensures the merged cell can be built no matter which part of it
is visible.
For example, if a cell is configured to span 3 columns, starting at column 1,
the cellBuilder of the TableView must return a TableViewCell with the
same child, columnMergeStart as 1, and columnMergeSpan as 3 for all
three TableVicinitys (column 1, 2, and 3). If the merge information is
only provided for the first vicinity (column 1), and that vicinity is
scrolled out of the viewport and cacheExtent, the table will not know the
following vicinities (column 2 and 3) are part of a merge and will "unmerge"
them.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- TableViewCell
- Implementers
- Available extensions
Constructors
Properties
- addRepaintBoundaries → bool
-
Whether to wrap each child in a RepaintBoundary.
final
- child → Widget
-
The child contained in this cell of the TableView.
final
- columnMergeSpan → int?
-
Represents the number of columns spanned by a merged cell.
final
- columnMergeStart → int?
-
Represents the column index where a merged cell in the table begins.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- rowMergeSpan → int?
-
Represents the number of rows spanned by a merged cell.
final
- rowMergeStart → int?
-
Represents the row index where a merged cell in the table begins.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
animate(
{Key? key, List< Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) → Animate -
Available on Widget, provided by the AnimateWidgetExtensions extension
Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex.myWidget.animate()is equivalent toAnimate(child: myWidget). -
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
positionedWith(
ShadPosition position) → Widget -
Available on Widget, provided by the PositionedExt extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited