alignment property
The alignment of the table within the viewport when there is extra space.
Implementation
final AlignmentGeometry alignment;
The alignment of the table within the viewport when there is extra space.
final AlignmentGeometry alignment;