rowCount property

  1. @override
int get rowCount
override

The number of rows that the tree has active nodes for.

The buildRow method will be called for TreeViewNodes that are currently active, meaning they are not contained within an unexpanded parent node.

The buildRow method must provide a valid TreeRow for all active nodes.

If the value returned by this getter changes throughout the lifetime of the delegate object, notifyListeners must be called.

Implementation

@override
int get rowCount => maxYIndex! + 1;
set rowCount (int value)

Implementation

set rowCount(int value) {
  assert(value >= 0);
  maxYIndex = value - 1;
}