alignment property

AlignmentGeometry alignment
final

The alignment of the tree within the viewport when there is extra space.

Currently, TreeView only supports the vertical component of alignment for aligning the tree within the viewport.

Defaults to Alignment.topLeft.

Implementation

final AlignmentGeometry alignment;