children property
List<TreeViewNode<T> >
get
children
Other TreeViewNodes that this node will be parent to.
Modifying the children of nodes in a TreeView will cause the tree to be rebuilt so that newly added active nodes are reflected in the tree.
Implementation
List<TreeViewNode<T>> get children => _children;