gaplessPlayback property
A boolean property that determines whether the image should have gapless playback. Default is false.
Implementation
final bool gaplessPlayback;
A boolean property that determines whether the image should have gapless playback. Default is false.
final bool gaplessPlayback;