FromValueTransformer<T> typedef
FromValueTransformer<T> =
T Function(dynamic value)
A function that transforms a value from a different format into the form field's expected type.
Takes a value of any type and returns a transformed value of type T.
Used to convert values before populating the form field.
Implementation
typedef FromValueTransformer<T> = T Function(dynamic value);