top property
An optional widget to display at the top of the alert, above the main content. This can be used to add additional information or controls.
Implementation
final Widget? top;
An optional widget to display at the top of the alert, above the main content. This can be used to add additional information or controls.
final Widget? top;