theme property
Default visual properties, like colors fonts and shapes, for this app's shad widgets.
A second darkTheme ShadThemeData value, which is used to provide a dark version of the user interface can also be specified. themeMode will control which theme will be used if a darkTheme is provided.
The default value of this property is the value of
ShadThemeData(brightness: Brightness.light).
Implementation
final ShadThemeData? theme;