type property
The type of app to use.
If you are going to use only Shad components, use ShadAppType.shadcn. If you are going to use also Material or Cupertino components, use ShadAppType.custom.
Implementation
final ShadAppType type;
The type of app to use.
If you are going to use only Shad components, use ShadAppType.shadcn. If you are going to use also Material or Cupertino components, use ShadAppType.custom.
final ShadAppType type;