ShadBorder class
A wrapper around the Border class with a reasonable merge.
- Implementers
- Available extensions
Constructors
- ShadBorder({bool canMerge = true, EdgeInsetsGeometry? padding, BorderRadiusGeometry? radius, ShadBorderSide? top, ShadBorderSide? right, ShadBorderSide? bottom, ShadBorderSide? left, double? offset})
-
A wrapper around the Border class with a reasonable merge.
const
- ShadBorder.all({bool canMerge = true, Color? color, double? width, BorderStyle? style, double? strokeAlign, EdgeInsetsGeometry? padding, BorderRadiusGeometry? radius, double? offset})
-
A uniform border with all sides the same color and width.
factory
- ShadBorder.fromBorderSide(ShadBorderSide side, {bool canMerge = true, EdgeInsetsGeometry? padding, BorderRadiusGeometry? radius, double? offset})
-
Creates a border whose sides are all the same.
const
- ShadBorder.symmetric({ShadBorderSide? vertical, ShadBorderSide? horizontal, bool canMerge = true, EdgeInsetsGeometry? padding, BorderRadiusGeometry? radius, double? offset})
-
Creates a border with symmetrical vertical and horizontal sides.
const
Properties
- bottom → ShadBorderSide?
-
final
- canMerge → bool
-
Whether to merge with another border, defaults to true.
final
- hasBorder → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- left → ShadBorderSide?
-
The left side of this border.
final
- offset → double?
-
The offset between the border and the widget.
final
- padding → EdgeInsetsGeometry?
-
The padding of the border, defaults to null.
final
- radius → BorderRadiusGeometry?
-
The border radius of the border, defaults to null.
final
- right → ShadBorderSide?
-
The right side of this border.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → ShadBorderSide?
-
The top side of this border.
final
Methods
-
copyWith(
{EdgeInsetsGeometry? padding, ShadBorderSide? top, ShadBorderSide? right, ShadBorderSide? bottom, ShadBorderSide? left, BorderRadiusGeometry? radius, double? offset}) → ShadBorder -
merge(
ShadBorder? other) → ShadBorder - Creates a ShadBorder that represents the addition of the two given ShadBorders.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBorder(
) → Border -
Available on ShadBorder, provided by the ShadBorderToBorder extension
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
ShadBorder? a, ShadBorder? b, double t) → ShadBorder?
Constants
- none → const ShadBorder