ShadBorderSide class
Creates the side of a border.
- Mixed-in types
- Available extensions
- Annotations
Constructors
- ShadBorderSide({bool canMerge = true, Color? color, double? width, BorderStyle? style, double? strokeAlign})
-
Creates the side of a border.
const
Properties
- canMerge → bool
-
Whether to merge the border side
final
- color → Color?
-
The color of this side of the border.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeAlign → double?
-
The relative position of the stroke on a ShadBorderSide in an
OutlinedBorder or Border.
final
- style → BorderStyle?
-
The style of this side of the border.
final
- width → double?
-
The width of this side of the border, in logical pixels.
final
Methods
-
copyWith(
{bool? canMerge, Color? color, double? width, BorderStyle? style, double? strokeAlign}) → ShadBorderSide - Creates a copy of this border but with the given fields replaced with the new values.
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
merge(
ShadBorderSide? other) → ShadBorderSide - Merges two border sides into one
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBorderSide(
) → BorderSide -
Available on ShadBorderSide, provided by the ShadBorderSideToBorderSide extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
lerp(
ShadBorderSide? a, ShadBorderSide? b, double t) → ShadBorderSide?
Constants
- none → const ShadBorderSide
- A hairline black border that is not rendered.