ShadContextMenuRegion constructor
const
ShadContextMenuRegion({
- Key? key,
- required Widget child,
- required List<
Widget> items, - bool? visible,
- BoxConstraints? constraints,
- ValueChanged<
bool> ? onHoverArea, - EdgeInsetsGeometry? padding,
- Object? groupId,
- List<
Effect> ? effects, - List<
BoxShadow> ? shadows, - ShadDecoration? decoration,
- ImageFilter? filter,
- ShadContextMenuController? controller,
- Set<
PointerDeviceKind> ? supportedDevices, - bool? longPressEnabled,
- bool? tapEnabled,
- HitTestBehavior hitTestBehavior = HitTestBehavior.opaque,
- Duration? popoverReverseDuration,
A widget that shows the context menu when the user right clicks the child or long presses it (only on android and ios), unless a value to longPressEnabled is provided.
On Android and iOS, tapping the child also shows the context menu by default. This can be overridden using tapEnabled.
Implementation
const ShadContextMenuRegion({
super.key,
required this.child,
required this.items,
this.visible,
this.constraints,
this.onHoverArea,
this.padding,
this.groupId,
this.effects,
this.shadows,
this.decoration,
this.filter,
this.controller,
this.supportedDevices,
this.longPressEnabled,
this.tapEnabled,
this.hitTestBehavior = HitTestBehavior.opaque,
this.popoverReverseDuration,
});