ShadForm class
A stateful widget that manages a form with validation and field management.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ShadForm
- Available extensions
Constructors
-
ShadForm({Key? key, required Widget child, VoidCallback? onChanged, bool? canPop, @Deprecated('Use onPopInvokedWithResult instead') void onPopInvoked(bool)?, PopInvokedWithResultCallback<
Object?> ? onPopInvokedWithResult, ShadAutovalidateMode autovalidateMode = ShadAutovalidateMode.alwaysAfterFirstValidation, Map<String, dynamic> initialValue = const {}, bool enabled = true, bool skipDisabled = false, bool clearValueOnUnregister = false, String? fieldIdSeparator = '.'}) -
const
Properties
- autovalidateMode → ShadAutovalidateMode
-
The auto validation mode for the form
final
- canPop → bool?
-
Whether the form can be popped from navigation
final
- child → Widget
-
The widget tree contained within the form
final
- clearValueOnUnregister → bool
-
Whether to clear the value of fields when they are unregistered, defaults
to false;
final
- enabled → bool
-
Whether the form fields are enabled
final
- fieldIdSeparator → String?
-
The separator to use for nested maps in the resulting form
ShadFormState.value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
initialValue
→ Map<
String, dynamic> -
Initial values for form fields
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onChanged → VoidCallback?
-
Callback when form value changes
final
- onPopInvoked → void Function(bool)?
-
final
-
onPopInvokedWithResult
→ PopInvokedWithResultCallback<
Object?> ? -
Callback when form is popped with a result
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipDisabled → bool
-
Whether to skip disabled fields during validation
final
Methods
-
animate(
{Key? key, List< Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) → Animate -
Available on Widget, provided by the AnimateWidgetExtensions extension
Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex.myWidget.animate()is equivalent toAnimate(child: myWidget). -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ShadForm> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
positionedWith(
ShadPosition position) → Widget -
Available on Widget, provided by the PositionedExt extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
maybeOf(
BuildContext context) → ShadFormState? - Returns the nearest ShadFormState from the widget tree or null if not found
-
of(
BuildContext context) → ShadFormState - Returns the nearest ShadFormState from the widget tree Throws assertion error if not found