onLineCountChange property
The callback that is called when the line count changes. The current line count is passed as an argument.
NOTE: If the input doesn't get an higher height, this callback won't be called. For example, if the maxLines limit has been reached.
Implementation
final ValueChanged<int>? onLineCountChange;