ShadLocalizationsData$timePicker$en class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hours → String
-
en: 'Hours'
no setter
- minutes → String
-
en: 'Minutes'
no setter
- period → String
-
en: 'Period'
no setter
- periodPlaceholder → String
-
en: 'AM'
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seconds → String
-
en: 'Seconds'
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited