ShadLocalizationsData class

Mixed-in types

Constructors

ShadLocalizationsData({Map<String, Node>? overrides, PluralResolver? cardinalResolver, PluralResolver? ordinalResolver, TranslationMetadata<ShadLocale, ShadLocalizationsData>? meta})
You can call this constructor and build your own translation instance of this locale. Constructing via the enum ShadLocale.build is preferred.

Properties

$meta TranslationMetadata<ShadLocale, ShadLocalizationsData>
Metadata of this root translation class
no setteroverride
$wip → dynamic
Provides the ability to write plain strings without code generation. Useful for prototyping / development.
no setterinherited
datePicker ShadLocalizationsData$datePicker$en
latefinal
hashCode int
The hash code for this object.
no setterinherited
input ShadLocalizationsData$input$en
latefinal
keyboardToolbar ShadLocalizationsData$keyboardToolbar$en
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timePicker ShadLocalizationsData$timePicker$en
latefinal

Methods

$copyWith({TranslationMetadata<ShadLocale, ShadLocalizationsData>? meta}) ShadLocalizationsData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String key) → dynamic
Access flat map