ShadMouseArea class
- Inheritance
- Available extensions
Constructors
- ShadMouseArea({Key? key, Widget? child, bool enabled = true, HitTestBehavior behavior = HitTestBehavior.deferToChild, Object? groupId, PointerEnterEventListener? onEnter, PointerExitEventListener? onExit, MouseCursor cursor = MouseCursor.defer, String? debugLabel})
-
Creates a const ShadMouseArea.
const
Properties
- behavior → HitTestBehavior
-
How to behave during hit testing when deciding how the hit test propagates
to children and whether to consider targets behind this ShadMouseArea.
final
- child → Widget?
-
The widget below this widget in the tree.
finalinherited
- cursor → MouseCursor
-
The mouse cursor for mouse pointers that are hovering over the region.
final
- debugLabel → String?
-
An optional debug label to help with debugging in debug mode.
final
- enabled → bool
-
Whether or not this ShadMouseArea is enabled as part of the composite
region.
final
- groupId → Object?
-
An optional group ID that groups ShadMouseAreas together so that they
operate as one region. If any member of a group is hit by a particular
hover, then all members will have their onEnter or onExit called.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onEnter → PointerEnterEventListener?
-
Triggered when a pointer enters the region.
final
- onExit → PointerExitEventListener?
-
Triggered when a pointer exits the region.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
animate(
{Key? key, List< Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) → Animate -
Available on Widget, provided by the AnimateWidgetExtensions extension
Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex.myWidget.animate()is equivalent toAnimate(child: myWidget). -
createElement(
) → SingleChildRenderObjectElement -
RenderObjectWidgets always inflate to a RenderObjectElement subclass.
inherited
-
createRenderObject(
BuildContext context) → RenderObject -
Creates an instance of the RenderObject class that this
RenderObjectWidget represents, using the configuration described by this
RenderObjectWidget.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
didUnmountRenderObject(
covariant RenderObject renderObject) → void -
This method is called when a RenderObject that was previously
associated with this widget is removed from the render tree.
The provided RenderObject will be of the same type as the one created by
this widget's createRenderObject method.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
positionedWith(
ShadPosition position) → Widget -
Available on Widget, provided by the PositionedExt extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
updateRenderObject(
BuildContext context, covariant ShadMouseAreaRenderBox renderObject) → void -
Copies the configuration described by this RenderObjectWidget to the
given RenderObject, which will be of the same type as returned by this
object's createRenderObject.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited