groupId property
Object?
get
groupId
An optional group ID that groups ShadMouseAreaRenderBoxs together so that they operate as one region. If any member of a group is hit by a particular hover, then all members will have their onEnter or onExit called.
If the group id is null, then only this region is hit tested.
Implementation
Object? get groupId => _groupId;
set
groupId
(Object? value)
Implementation
set groupId(Object? value) {
if (_groupId != value) {
// If the group changes, we need to unregister and re-register under the
// new group. The re-registration happens automatically in layout().
if (_isRegistered) {
_registry!.unregisterMouseArea(this);
_isRegistered = false;
}
_groupId = value;
markNeedsLayout();
}
}