ShadProviderIndex class
An immutable class that holds an index.
Used by ShadIndexProvider to provide the index to the child widget.
- Annotations
Constructors
- ShadProviderIndex(int index)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited