ShadResizableController class
- Inheritance
-
- Object
- ChangeNotifier
- ShadResizableController
Constructors
Properties
- base → double
-
The total size of all registered panels, used to calculate available
space for resizing.
no setter
-
defaultSizes
→ List<
double> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
-
panelsInfo
→ List<
ShadPanelInfo> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalAvailableWidth ↔ double
-
getter/setter pair
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
clear(
) → void - Clear all the panel info and default sizes
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
getPanelInfo(
int index) → ShadPanelInfo - This method retrieves the information of a panel at the specified index. Throws an exception if the index is out of bounds.
-
insertPanel(
int index, ShadPanelInfo info) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
registerPanel(
ShadPanelInfo info) → int - This method adds a new panel to the controller and returns its index.
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
resetDefaultSizes(
int leadingIndex, int trailingIndex) → void - Reset the default sizes of the leading and trailing panels.
-
resize(
{required double delta, required List< double> initialLayout, required List<int> pivotIndices}) → ShadResizeResult - Adjusts the layout using an absolute percentage delta from the initial layout snapshot (captured at drag start).
-
toString(
) → String -
A string representation of this object.
inherited
-
unregisterPanel(
Object id) → void -
update(
List< ShadPanelInfo> panels) → void -
Update the panel info with the given
panels
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited