getPanelInfo method
This method retrieves the information of a panel at the specified index. Throws an exception if the index is out of bounds.
Implementation
ShadPanelInfo getPanelInfo(int index) {
final contains = panelsInfo.length > index;
if (!contains) throw Exception('Panel info not found for index: $index');
return panelsInfo[index];
}