id property
The unique identifier for the panel. This ID must be unique among all panels in the group to ensure proper management and resizing behavior.
Implementation
final Object id;
The unique identifier for the panel. This ID must be unique among all panels in the group to ensure proper management and resizing behavior.
final Object id;