ShadResizableTheme class
- Annotations
-
- @themeGen
- @immutable
Constructors
- ShadResizableTheme({bool canMerge = true, MainAxisAlignment? mainAxisAlignment, CrossAxisAlignment? crossAxisAlignment, MainAxisSize? mainAxisSize, TextDirection? textDirection, VerticalDirection? verticalDirection, bool? showHandle, IconData? handleIconData, double? dividerSize, bool? resetOnDoubleTap, ShadDecoration? handleDecoration, EdgeInsetsGeometry? handlePadding, double? handleSize, double? dividerThickness, Color? dividerColor})
-
const
Properties
- canMerge → bool
-
no setter
- crossAxisAlignment → CrossAxisAlignment?
-
The alignment of the panels along the cross axis.
final
- dividerColor → Color?
-
The color of the divider between panels.
final
- dividerSize → double?
-
The size of the divider between panels.
final
- dividerThickness → double?
-
The thickness of the divider between panels.
final
- handleDecoration → ShadDecoration?
-
Custom decoration for the resize handle.
final
- handleIconData → IconData?
-
The icon data for the resize handle.
final
- handlePadding → EdgeInsetsGeometry?
-
Padding around the resize handle.
final
- handleSize → double?
-
The size of the resize handle icon.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mainAxisAlignment → MainAxisAlignment?
-
The alignment of the panels along the main axis.
final
- mainAxisSize → MainAxisSize?
-
The size of the main axis for the panels.
final
- resetOnDoubleTap → bool?
-
Whether to reset the panel sizes on double-tap of the divider.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showHandle → bool?
-
Whether to show the resize handle between panels.
final
- textDirection → TextDirection?
-
The text direction for the panels' content.
Can be set to TextDirection.ltr or TextDirection.rtl.
final
- verticalDirection → VerticalDirection?
-
The vertical direction for the panels' layout.
Can be set to VerticalDirection.down or VerticalDirection.up.
final
Methods
-
copyWith(
{MainAxisAlignment? mainAxisAlignment, CrossAxisAlignment? crossAxisAlignment, MainAxisSize? mainAxisSize, TextDirection? textDirection, VerticalDirection? verticalDirection, bool? showHandle, IconData? handleIconData, double? dividerSize, bool? resetOnDoubleTap, ShadDecoration? handleDecoration, EdgeInsetsGeometry? handlePadding, double? handleSize, double? dividerThickness, Color? dividerColor}) → ShadResizableTheme -
inherited
-
merge(
ShadResizableTheme? other) → ShadResizableTheme -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
ShadResizableTheme? a, ShadResizableTheme? b, double t) → ShadResizableTheme?