toInnerExpandableAlignment method
Returns the alignment for the inner ShadDialog in expandable mode.
Aligns the content cluster adjacent to the drag pill so there is no gap between the pill and the visible content area.
Implementation
Alignment toInnerExpandableAlignment() {
return switch (this) {
ShadSheetSide.bottom => Alignment.topCenter,
ShadSheetSide.top => Alignment.bottomCenter,
ShadSheetSide.left => Alignment.centerRight,
ShadSheetSide.right => Alignment.centerLeft,
};
}