ToastInfo class
Constructors
Properties
- controller → AnimationController
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → Object
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- temporarelyHide ↔ bool
-
getter/setter pair
- timer ↔ Timer?
-
getter/setter pair
- toast → ShadToast
-
final
- visible ↔ bool
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited